==> github-widget2-1.0.0.tgz: package/lib/test/milestones.test.js <==
'use strict';

var _jsxFileName = '../../src/test/milestones.test.jsx';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Milestones = require('../components/Milestones/Milestones');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        milestones: {
          ids: ['2601714']
        },
        milestonesById: {
          2601714: {
            created: '2017-06-23T22:45:34Z',
            labels: [],
            repoIssueNumber: 36,
            title: 'disregard this PR'
          }
        },
        loadingMilestones: false,
        currentPage: { userName: 'michaelmurray6298' }
      }
    }
  }
};

describe('Milestones component', function () {
  it('should render a component with props as specified ', function () {
    var retrieveMilestones = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Milestones.Milestones, { loadingMilestones: false, retrieveMilestones: retrieveMilestones, __source: {
        fileName: _jsxFileName,
        lineNumber: 36
      },
      __self: undefined
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it("map's given State To Props ", function () {
    var expected = {
      loadingMilestones: false,
      userName: 'michaelmurray6298',
      orgName: undefined,
      milestonesById: undefined,
      milestonesByRepo: undefined
    };
    expect((0, _Milestones.mapStateToProps)(state, { widgetId: 'github' })).toEqual(expected);
  });

  it('maps component dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _Milestones.mapDispatchToProps)(dispatch)).toHaveProperty('retrieveMilestones');
  });

  it('Should have a Cart Header in the center', function () {
    var retrieveMilestones = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Milestones.Milestones, {
      loadingMilestones: false,
      retrieveMilestones: retrieveMilestones,
      userName: state.widgets.byId.github.currentPage.userName,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 60
      },
      __self: undefined
    }));
    expect(component.find('.aligned').exists()).toBe(true);
  });
});

==> github-widget2-1.0.4.tgz: package/lib/test/milestones.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Milestones = require('../components/Milestones/Milestones');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        milestones: {
          ids: ['2601714']
        },
        milestonesById: {
          2601714: {
            created: '2017-06-23T22:45:34Z',
            labels: [],
            repoIssueNumber: 36,
            title: 'disregard this PR'
          }
        },
        loadingMilestones: false,
        currentPage: { userName: 'michaelmurray6298' }
      }
    }
  }
};

describe('Milestones component', function () {
  it('should render a component with props as specified ', function () {
    var retrieveMilestones = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Milestones.Milestones, { loadingMilestones: false, retrieveMilestones: retrieveMilestones }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it("map's given State To Props ", function () {
    var expected = {
      loadingMilestones: false,
      userName: 'michaelmurray6298',
      orgName: undefined,
      milestonesById: undefined,
      milestonesByRepo: undefined
    };
    expect((0, _Milestones.mapStateToProps)(state, { widgetId: 'github' })).toEqual(expected);
  });

  it('maps component dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _Milestones.mapDispatchToProps)(dispatch)).toHaveProperty('retrieveMilestones');
  });

  it('Should have a Cart Header in the center', function () {
    var retrieveMilestones = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Milestones.Milestones, {
      loadingMilestones: false,
      retrieveMilestones: retrieveMilestones,
      userName: state.widgets.byId.github.currentPage.userName
    }));
    expect(component.find('.aligned').exists()).toBe(true);
  });
});
